==> qgis-3.0.3-1-aarch64.pkg.tar.xz: usr/share/qgis/python/plugins/processing/algs/grass7/ext/v_voronoi.py <==
# -*- coding: utf-8 -*-

"""
***************************************************************************
    v_voronoi.py
    ------------
    Date                 : February 2016
    Copyright            : (C) 2016 by Médéric Ribreux
    Email                : medspx at medspx dot fr
***************************************************************************
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
***************************************************************************
"""

__author__ = 'Médéric Ribreux'
__date__ = 'February 2016'
__copyright__ = '(C) 2016, Médéric Ribreux'

# This will get replaced with a git SHA1 when you do a git archive

__revision__ = '8a899c8758b30adc3f8d6df682a5702dd3bfe6f0'


def processInputs(alg, parameters, context, feedback):
    if 'input' in alg.exportedLayers:
        return

    # We need to use v.in.ogr instead of v.external
    alg.loadVectorLayerFromParameter('input', parameters, context, feedback, False)
    alg.processInputs(parameters, context, feedback)


def processOutputs(alg, parameters, context, feedback):
    fileName = alg.parameterAsOutputLayer(parameters, 'output', context)
    grassName = '{}{}'.format('output', alg.uniqueSuffix)
    dataType = 'auto'
    # if we export a graph, output type will be a line
    if alg.parameterAsBool(parameters, '-l', context):
        dataType = 'line'

    alg.exportVectorLayer(grassName, fileName, dataType)

==> qgis-3.2.3-1-aarch64.pkg.tar.xz: usr/share/qgis/python/plugins/processing/algs/grass7/ext/v_voronoi.py <==
# -*- coding: utf-8 -*-

"""
***************************************************************************
    v_voronoi.py
    ------------
    Date                 : February 2016
    Copyright            : (C) 2016 by Médéric Ribreux
    Email                : medspx at medspx dot fr
***************************************************************************
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
***************************************************************************
"""

__author__ = 'Médéric Ribreux'
__date__ = 'February 2016'
__copyright__ = '(C) 2016, Médéric Ribreux'

# This will get replaced with a git SHA1 when you do a git archive

__revision__ = '9b176802e5512bc310765d8ebe4e44b5f4663453'


def processInputs(alg, parameters, context, feedback):
    if 'input' in alg.exportedLayers:
        return

    # We need to use v.in.ogr instead of v.external
    alg.loadVectorLayerFromParameter('input', parameters, context, feedback, False)
    alg.processInputs(parameters, context, feedback)


def processOutputs(alg, parameters, context, feedback):
    fileName = alg.parameterAsOutputLayer(parameters, 'output', context)
    grassName = '{}{}'.format('output', alg.uniqueSuffix)
    dataType = 'auto'
    # if we export a graph, output type will be a line
    if alg.parameterAsBool(parameters, '-l', context):
        dataType = 'line'

    alg.exportVectorLayer(grassName, fileName, dataType=dataType)
